@@ -13,7 +13,7 @@
 
 SECTION(p2p);
 
-static int handle_p2p_start(struct nl80211_state *state, struct nl_cb *cb,
+static int handle_p2p_start(struct nl80211_state *state,
 			    struct nl_msg *msg, int argc, char **argv,
 			    enum id_input id)
 {
@@ -21,7 +21,7 @@ static int handle_p2p_start(struct nl80211_state *state, struct nl_cb *cb,
 }
 COMMAND(p2p, start, "", NL80211_CMD_START_P2P_DEVICE, 0, CIB_WDEV, handle_p2p_start, "");
 
-static int handle_p2p_stop(struct nl80211_state *state, struct nl_cb *cb,
+static int handle_p2p_stop(struct nl80211_state *state,
 			   struct nl_msg *msg, int argc, char **argv,
 			   enum id_input id)
 {
